==> ove-pro-test-18.3.12.tgz: package/es/ToolBar/inlineFindTool.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React from "react";
import { Icon } from "@blueprintjs/core";
import FindBar from "../FindBar";
import ToolbarItem from "./ToolbarItem";
import { connectToEditor } from "../withEditorProps";
export default connectToEditor(function (_ref) {
  var _ref$findTool = _ref.findTool,
    findTool = _ref$findTool === void 0 ? {} : _ref$findTool;
  return {
    isOpen: findTool.isOpen
  };
})(function (_ref2) {
  var toolbarItemProps = _ref2.toolbarItemProps,
    editorName = _ref2.editorName,
    toggleFindTool = _ref2.toggleFindTool,
    isOpen = _ref2.isOpen;
  return /*#__PURE__*/React.createElement(ToolbarItem, _extends({
    Icon: !isOpen ? /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Icon, {
      "data-test": "ve-find-tool-toggle",
      icon: "search"
    }), /*#__PURE__*/React.createElement(Icon, {
      icon: "caret-right"
    })) : /*#__PURE__*/React.createElement(FindBar, {
      editorName: editorName
    }),
    renderIconAbove: isOpen,
    onIconClick: toggleFindTool,
    tooltip: isOpen ? /*#__PURE__*/React.createElement("span", null, "Hide Find Tool ", /*#__PURE__*/React.createElement("span", {
      style: {
        fontSize: 10
      }
    }, "(Cmd/Ctrl+F)")) : /*#__PURE__*/React.createElement("span", null, "Show Find Tool ", /*#__PURE__*/React.createElement("span", {
      style: {
        fontSize: 10
      }
    }, "(Cmd/Ctrl+F)"))
  }, toolbarItemProps));
});

==> ove-pro-test-18.3.24.tgz: package/es/ToolBar/inlineFindTool.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React from "react";
import { Icon } from "@blueprintjs/core";
import FindBar from "../FindBar";
import ToolbarItem from "./ToolbarItem";
import { connectToEditor } from "../withEditorProps";
export default connectToEditor(function (_ref) {
  var _ref$findTool = _ref.findTool,
    findTool = _ref$findTool === void 0 ? {} : _ref$findTool;
  return {
    isOpen: findTool.isOpen
  };
})(function (_ref2) {
  var toolbarItemProps = _ref2.toolbarItemProps,
    editorName = _ref2.editorName,
    toggleFindTool = _ref2.toggleFindTool,
    isOpen = _ref2.isOpen;
  return /*#__PURE__*/React.createElement(ToolbarItem, _extends({
    Icon: !isOpen ? /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Icon, {
      "data-test": "ve-find-tool-toggle",
      icon: "search"
    }), /*#__PURE__*/React.createElement(Icon, {
      icon: "caret-right"
    })) : /*#__PURE__*/React.createElement(FindBar, {
      editorName: editorName
    }),
    renderIconAbove: isOpen,
    onIconClick: toggleFindTool,
    tooltip: isOpen ? /*#__PURE__*/React.createElement("span", null, "\u9690\u85CF\u67E5\u627E\u5DE5\u5177 ", /*#__PURE__*/React.createElement("span", {
      style: {
        fontSize: 10
      }
    }, "(Cmd/Ctrl+F)")) : /*#__PURE__*/React.createElement("span", null, "\u663E\u793A\u67E5\u627E\u5DE5\u5177 ", /*#__PURE__*/React.createElement("span", {
      style: {
        fontSize: 10
      }
    }, "(Cmd/Ctrl+F)"))
  }, toolbarItemProps));
});
